package Bundle::IO::Compress::Bzip2;

use strict;

$Bundle::IO::Compress::Bzip2::VERSION = '2.039';

1;
__END__

=head1 NAME

Bundle::IO::Compress::Bzip2 - Install IO::Compress::Bzip2 and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::IO::Compress::Bzip2'

=head1 CONTENTS

Scalar::Util

Compress::Raw::Bzip2 2.039

Compress::Raw::Zlib 2.039

IO::Compress::Bzip2 2.039

=head1 AUTHOR

This module was written by Paul Marquess, F<pmqs@cpan.org>.

=head1 MODIFICATION HISTORY

See the Changes file.

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2008-2011 Paul Marquess. All rights reserved.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

